@@ -46,6 +46,9 @@
 //! The `python3-config` binary in this crate is Python 3 only.
 
 mod cmdr;
+#[macro_use]
+mod script;
+
 use cmdr::SysCommand;
 
 use semver;
@@ -113,13 +116,16 @@ fn other_err(what: &'static str) -> Error {
     Error::Other(what)
 }
 
+/// Defines the script with a common prelude of imports
+/// and helper functions. Returns a single string that
+/// represents the script.
 fn build_script(lines: &[&str]) -> String {
     let mut script = String::new();
-    script.push_str("from __future__ import print_function; ");
-    script.push_str("import sysconfig; ");
-    script.push_str("pyver = sysconfig.get_config_var('VERSION'); ");
-    script.push_str("getvar = sysconfig.get_config_var; ");
-    script.push_str(&lines.join("; "));
+    script.push_str("from __future__ import print_function\n");
+    script.push_str("import sysconfig\n");
+    script.push_str("pyver = sysconfig.get_config_var('VERSION')\n");
+    script.push_str("getvar = sysconfig.get_config_var\n");
+    script.push_str(&lines.join("\n"));
     script
 }
 
@@ -213,7 +219,7 @@ impl PythonConfig {
     /// [`semantic_version`](struct.PythonConfig.html#method.semantic_version)
     /// for something more useful.
     pub fn version_raw(&self) -> PyResult<String> {
-        self.cmdr.command("--version").map_err(From::from)
+        self.cmdr.commands(&["--version"]).map_err(From::from)
     }
 
     /// Returns the Python version as a semver
@@ -238,7 +244,7 @@ impl PythonConfig {
 
     /// Returns the installation prefix of the Python interpreter as a string
     pub fn prefix(&self) -> PyResult<String> {
-        self.script(&["print(sysconfig.get_config_var('prefix'))"])
+        self.script(&["print(getvar('prefix'))"])
     }
 
     /// Like [`prefix`](#method.prefix), but returns
@@ -249,7 +255,7 @@ impl PythonConfig {
 
     /// Returns the executable path prefix for the Python interpreter as a string
     pub fn exec_prefix(&self) -> PyResult<String> {
-        self.script(&["print(sysconfig.get_config_var('exec_prefix'))"])
+        self.script(&["print(getvar('exec_prefix'))"])
     }
 
     /// Like [`exec_prefix`](#method.exec_prefix), but
@@ -286,7 +292,9 @@ impl PythonConfig {
     pub fn cflags(&self) -> PyResult<String> {
         self.script(&[
             "flags = ['-I' + sysconfig.get_path('include'), '-I' + sysconfig.get_path('platinclude')]",
-            "flags.extend(sysconfig.get_config_var('CFLAGS').split())",
+            linux_line!("flags.extend(getvar('BASECFLAGS').split())"),
+            linux_line!("flags.extend(getvar('CONFIGURE_CFLAGS').split())"),
+            macos_line!("flags.extend(getvar('CFLAGS').split())"),
             "print(' '.join(flags))",
         ])
     }
@@ -311,10 +319,13 @@ impl PythonConfig {
         self.script(&[
             "import sys",
             "libs = ['-lpython' + pyver + sys.abiflags]",
+            linux_line!["libs.insert(0, '-L' + getvar('exec_prefix') + '/lib')"],
             "libs += getvar('LIBS').split()",
             "libs += getvar('SYSLIBS').split()",
-            "libs.insert(0, '-L' + getvar('LIBPL')) if not getvar('Py_ENABLE_SHARED') else None",
-            "libs.extend(getvar('LINKFORSHARED').split()) if not getvar('PYTHONFRAMEWORK') else None",
+            "if not getvar('Py_ENABLED_SHARED'):",
+            tab!("libs.insert(0, '-L' + getvar('LIBPL'))"),
+            "if not getvar('PYTHONFRAMEWORK'):",
+            tab!("libs.extend(getvar('LINKFORSHARED').split())"),
             "print(' '.join(libs))",
         ])
     }
@@ -325,7 +336,7 @@ impl PythonConfig {
     /// feature parity with the `python3-config` script.
     pub fn extension_suffix(&self) -> Py3Only<String> {
         self.is_py3()?;
-        let resp = self.script(&["print(sysconfig.get_config_var('EXT_SUFFIX'))"])?;
+        let resp = self.script(&["print(getvar('EXT_SUFFIX'))"])?;
         Ok(resp)
     }
 
@@ -345,7 +356,7 @@ impl PythonConfig {
     /// feature parity with the `python3-config` script.
     pub fn config_dir(&self) -> Py3Only<String> {
         self.is_py3()?;
-        let resp = self.script(&["print(sysconfig.get_config_var('LIBPL'))"])?;
+        let resp = self.script(&["print(getvar('LIBPL'))"])?;
         Ok(resp)
     }
 
